﻿using Microsoft.Win32;
using MyWpfApp.models;
using System;
using System.Collections.Generic;
using System.Data.Entity;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using static System.Net.Mime.MediaTypeNames;

namespace MyWpfApp.Pages
{
    /// <summary>
    /// Логика взаимодействия для PageUserInfo.xaml
    /// </summary>
    public partial class PageUserInfo : Page
    {
        User user;


        int status;//флаг, который указывает, создаем мы нового пользователя или редактируем существующего

        /// <summary>
        /// конструктор с одним аргументом. если мы смотрим информацию о существующем пользователе
        /// </summary>
        /// <param name="currentUser">Пользователь, о котором мы хотим видеть информацию</param>
        public PageUserInfo(LoginedTable currentUser)
        {
            InitializeComponent();
            user = new User(currentUser);
            DataContext = user;

            status = 1;//редактируем существующего пользователя
            CBRoles.ItemsSource = Globals.MyGlobalConnection.Roles.ToList();//источник данных для элементов списка
            CBRoles.SelectedValuePath = "ID"; //какое значение (что конкретно) вернется при выборе пункта списка
            CBRoles.DisplayMemberPath = "Role";// что будет видно пользователю при отображении элементов списка

        }

        /// <summary>
        /// конструктор, если мы создаем нового пользователя
        /// </summary>
        public PageUserInfo()
        {
            InitializeComponent();            
           user = new User();
           DataContext = user;
            status = 0;//создаем нового пользователя
            CBRoles.ItemsSource = Globals.MyGlobalConnection.Roles.ToList();//источник данных для элементов списка
            CBRoles.SelectedValuePath = "ID"; //какое значение (что конкретно) вернется при выборе пункта списка
            CBRoles.DisplayMemberPath = "Role";// что будет видно пользователю при отображении элементов списка
        }
        private void BtnBack_Click(object sender, RoutedEventArgs e)
        {
            Globals.MyGlobalFrame.GoBack();//так переходим на предыдущую страницу
        }

        private void BtnSave_Click(object sender, RoutedEventArgs e)
        {
           if (status == 0)//если создаем нового пользователя, то добавляем информацию о нем в базу
            {
                Globals.MyGlobalConnection.LoginedTable.Add(user.LoginedTable);//сначала создаем LoginedTable, т.к. она для нашей связи 1 к 1 первичный ключ
                Globals.MyGlobalConnection.SaveChanges();//для того, чтобы у user.LoginedTable появился ID, который создается на стороне SQL-сервера
                Globals.MyGlobalConnection.UserTable.Add(user.UserTable);//добавляем вторую таблицу (которая содержит внешний ключ)
            }
           Globals.MyGlobalConnection.SaveChanges();//сохраняем изменения в любом случае (ка при добавлении, так и при редактировании)
            MessageBox.Show("Сохранено");//информационное сообщение
        }

       
        private void btnChangeUserImage_Click(object sender, RoutedEventArgs e)
        {
            
           
            OpenFileDialog OFD = new OpenFileDialog();
            OFD.Filter = "Все файлы | *.*; | Изображения |*.jpg;*.png;";
            bool? success = OFD.ShowDialog();


            ImageConverter imageConverter = new ImageConverter();

            //создаем объект изображения по известному пути к картинке
            System.Drawing.Image image = System.Drawing.Image.FromFile(OFD.FileName);

            //преобразуем картинку в массив байт
            byte[] bytes = (byte[])imageConverter.ConvertTo(image, typeof(byte[]));

            //добавляем запись в таблицу с картинками и сохраняем изменения
            Globals.MyGlobalConnection.UserImages.Add(new UserImages(){IDUser = user.UserTable.ID, Image = bytes });
            Globals.MyGlobalConnection.SaveChanges();

            //метод для обновления картинки
            user.RefrashImage();

         }
    }
}
